@@ -11,7 +11,7 @@ Various Format descriptions for MagPy.
 
 # import order matters - NamedTemporaryFile must be one of the first!
 __all__ = ['lib','opt','stream','absolutes','transfer','database']
-from stream import *
-from absolutes import *
-from transfer import *
-from database import *
+from magpy.stream import *
+from magpy.absolutes import *
+from magpy.transfer import *
+from magpy.database import *
