@@ -6,8 +6,8 @@ Written by Roman Leonhardt October 2012
 ToDo: Filter for minute data
 """
 
-from stream import *
-
+from magpy.stream import *
+from datetime import timedelta
 
 def isWDC(filename):
     """
@@ -27,7 +27,7 @@ def isWDC(filename):
 def readWDC(filename, headonly=False, **kwargs):
     """
     Reading WDC format data.
-    Looks like:
+    Hourly looks like:
     WIK1209F01  20 4355059506150605058505950585053504750395034503850385043504850515049505150545056505750575057506050575052
     WIK1209F02  20 4355056505950565055505750515049504150395036503750405041504550565059506250605058506750565053505250495052
     WIK1209F03  20 4355047505050535054505550525045503950315021502050315053505250605064506750685071506550615067505950625052
@@ -456,6 +456,213 @@ def writeWDC(datastream, filename, **kwargs):
     else:
         logging.warning("Could not save WDC data. Please provide hour or minute data")
 
+    # 3.)
+    if minute:
+        '''
+COLUMNS   FORMAT   DESCRIPTION
+
+1-6       I6       Observatory's North Polar distance.  
+                   the north geographic pole in thousandths 
+                   of a degree. Decimal point is implied between positions 3 
+                   and 4.
+7-12      I6       Observatory's Geographic longitude. 
+                   of a degree. Decimal point is implied between positions 9 
+                   and 10.
+13-14     I2       Year. Last 2 digits, 1996 = 96. See also column 26.
+15-16     I2       Month (01-12)
+17-18     I2       Day of month (01-31)
+19        Al       Element (D,I,H,X,Y,Z, or F)
+20-21     I2       Hour of day (00-23)
+22-24     A3       Observatory 3-letter code.
+25        A1       Arbitrary.
+26        I1       Century digit.
+                   Year = 2014, Century digit = 0.
+                   Year = 1889, Century digit = 8.
+                   Year = 1996, Century digit = 9 or 'SPACE' for backwards
+                   compatibility.
+27        A1       Preliminary or Definitive data.
+                   Preliminary = P , Definitive = D
+28-34     A7       Blanks
+35-394    60I6     60 6-digit 1-minute values for the given element for that
+                   data hour.
+                   The values are in tenth-minutes for D and I, and in
+                   nanoTeslas for the intensity elements.
+395-400   I6       Hourly Mean.
+                   The average of the preceeding 60 1-minute values.
+401-402            Record end marker.
+                   Two chars 'cr'= 13 and 'nl'= 10.
+        '''
+
+	# http://www.wdc.bgs.ac.uk/catalog/format.html
+	data_predef = 'P' # P for preliminary, D for definitive. TODO: change this later
+        min_dict, hour_dict, day_dict = {}, {}, {}
+	write_KEYLIST = ['x','y','z','f']
+        for key in write_KEYLIST:
+            min_dict[key] = ''
+        day, hour = '0', '0'
+
+        for day in range(1,32):		# TODO: make this exact for given month
+            day_dict[str(day).zfill(2)] = ''
+
+	# Read data into dictionaries for ease of writing:
+        for elem in datastream:
+	    timestamp = num2date(elem.time).replace(tzinfo=None)
+	    minute = datetime.strftime(timestamp, "%M")
+            if minute == '00':
+                if len(min_dict['x']) != 360:
+                    loggerlib.error('format_wdc: Error in formatting data for %s.' % datetime.strftime(timestamp,'%Y-%m-%d %H:%M'))
+                minutedata = dict(min_dict)
+                hour_dict[hour] = minutedata
+                for key in write_KEYLIST:
+                    min_dict[key] = ''
+            hour = datetime.strftime(timestamp, "%H")
+            if hour == '00' and minute == '00':
+                hourdata = dict(hour_dict)
+                day_dict[day] = hourdata
+                for hour in range(0,24):
+                    hour_dict[str(hour).zfill(2)] = ''
+            year = datetime.strftime(timestamp, "%Y")
+            day = datetime.strftime(timestamp, "%d")
+            for key in write_KEYLIST:
+                exec('value = elem.'+key)
+                if not isnan(value):
+                    if len(str(value)) > 6:
+                        if value >= 10000:
+                            value = int(round(value))
+			elif value >= 1000:
+                            value = round(value,1)
+			else:
+			    value = round(value,2)
+                    val_f = str(value).rjust(6)
+                else:
+                    val_f = '999999'
+                min_dict[key] = min_dict[key] + val_f
+
+	# Save last day of data, which is left out in loop:
+	minutedata = dict(min_dict)
+	hour_dict[hour] = minutedata
+	hourdata = dict(hour_dict)
+        day_dict[day] = hourdata
+
+	# Find data for preamble tags at line beginning:
+        ar = year[2:]
+        ye = year[:-2]
+        century = ye[1:]
+        month = datetime.strftime(timestamp, "%m")
+
+        header = datastream.header
+	try:
+            iagacode = header.get('StationIAGAcode'," ").upper()
+	except:
+	    iagacode = 'WIC'
+	try:
+	    station_lat = header.get('DataAcquisitionLatitude'," ")
+	except:
+	    station_lat = 47.93
+	try:
+	    station_long = header.get('DataAcquisitionLongitude'," ")
+	except:
+	    station_long = 15.865
+	northpolardistance = int(round((90-float(station_lat))*1000))
+	longitude = int(round(float(station_long) * 1000))
+
+	pre_geopos = str(northpolardistance).rjust(6) + str(longitude).rjust(6)
+	day = datetime(int(year),int(month),1)
+
+	# TODO write routine to check for missing data and fill in spaces?
+
+	# Find time range:
+	if int(month) < 12:
+	    nextmonth = datetime(int(year),int(month)+1,1)
+	else:
+	    nextmonth = datetime(int(year)+1,1,1)
+
+	# Write data in beliebiges Format:
+	while day < nextmonth:
+	    for key in write_KEYLIST:
+                for hour_ in range(0,24):
+		    hour = str(hour_).zfill(2)
+		    dom = datetime.strftime(day,"%d")
+	            pre_date = ar + month + datetime.strftime(day,'%d')
+	            pre_rest = key.upper() + hour + iagacode + ' ' + century + data_predef + '       '
+		    preamble = pre_geopos + pre_date + pre_rest
+
+		    # Get data + calculate mean:
+                    try:
+		        data = day_dict[dom][hour][key]
+		        total = 0.
+			try:
+		            for i in range(0,60):
+		                total = total + float(data[i*6:(i+1)*6])
+		            hourly_mean = total/60.
+			except:
+			    hourly_mean = 999999
+                        if len(str(hourly_mean)) > 6:
+                            if hourly_mean >= 10000:
+                                hourly_mean = int(round(hourly_mean))
+			    elif hourly_mean >= 1000:
+                                hourly_mean = round(hourly_mean,1)
+			    else:
+				hourly_mean = round(hourly_mean,2)
+                        hourly_mean = str(hourly_mean).rjust(6)
+		    except KeyError:
+			loggerlib.warning('format_wdc: key It appears there is missing data for date %s. Replacing with 999999.'
+				% (datetime.strftime(day,'%Y-%m-%d ')+hour+':00'))
+			data = '999999'*60
+		        hourly_mean = '999999'
+		    except TypeError:
+			loggerlib.warning('format_wdc: type It appears there is missing data for date %s. Replacing with 999999.'
+				% (datetime.strftime(day,'%Y-%m-%d ')+hour+':00'))
+			data = '999999'*60
+		        hourly_mean = '999999'
+		    if len(data) != 360:
+			loggerlib.warning('format_wdc: It appears there is missing data for date %s. Replacing with 999999.'
+				% (datetime.strftime(day,'%Y-%m-%d ')+hour+':00'))
+			data = '999999'*60
+		        hourly_mean = '999999'
+		    line = preamble + data + hourly_mean + '\n'
+		    myFile.write(line)
+            day = day + timedelta(days=1)
+
+        '''
+        # Finally save data of the last day, which dropped out by above procedure
+        for comp in ['x','y','z','f']:
+            if len(eval(comp+'el'))<1:
+                exec(comp+'dailymean = int(9999)')
+                exec(comp+'base = int(9999)') 
+            else:
+                exec(comp+'mean = round(np.mean(' + comp +'el),0)') 
+                exec(comp+'base = ' + comp +'mean - 5000.0') 
+                exec(comp+'base = int(' + comp +'base/100)') 
+                exec(comp+'dailymean = int(' + comp +'mean - ' + comp +'base*100)') 
+            exec('row'+comp+'+= "%4i" % '+comp+'base')
+            count = 0
+            for i in range(24):
+                if len(eval(comp+'hourel')) > 0 and count < len(eval(comp+'hourel')) and eval(comp+'hourel[count]') == i:
+                    exec(comp+'val = int(' + comp +'el[count] - ' + comp + 'base*100)')
+                    count = count+1
+                else:
+                    exec(comp+'val = int(9999)')
+                    exec(comp+'dailymean = int(9999)')
+                exec('row' + comp + '+="%4i" % ' + comp + 'val')
+            eol = '\n'
+            exec('row' + comp + '+="%4i%s" % (' + comp + 'dailymean,eol)')
+            line.append(eval('row'+comp))
+        line.sort()
+        try:
+            myFile.writelines( line )
+            pass
+        finally:
+           myFile.close()
+        #except IOError:
+        #    pass
+    elif minute:
+        pass
+    else:
+        logging.warning("Could not save WDC data. Please provide hour or minute data")
+        '''
+   
+
 """
 def textable_preamble(fp, kwargs**):
 TEX Table generator
